#ifndef __FREEMSG_H__
#define __FREEMSG_H__

#define AF_DOALERT		0x4564
/* AF_DOALERT: Aufforderung, eine Alertbox zu ffnen
 * Word 3:   Default-Button (Bit 4 gesetzt: System-Modal ffnen)
 * Word 4/5: Alert-String
 * Word 6/7: Zeiger auf App-Namen, der als Fensterberschrift
 			 gesetzt werden soll oder NULL, dann ermittelt Freedom
			 einen per Xacc/AV/appl_search
 */

#define FA_ALERTISOPEN	0x4565
/* AF_ALERTISTOPEN: Alertbox wurde geffnet
 * Word 3: Alert-(Fenster-)Handle (-1 = Fehler)
 * Word 4/5: Der bergebene Alert-String
 * Word 6/7: Der bergebene Alert-Titel
 */

#define FA_ALERTDONE	0x4566
/* FA_ALERTDONE: Alert wurde geschlossen
 * Word 3: Alert-(Fenster-)Handle
 * Word 4: Gedrckter Batten
 */

#define AF_DOFSELECT	0x4567
/* AF_DOFSELECT: Aufforderung, einen Fensterfileselektor zu 
 * ffnen. Als Antwort kommt FA_FSELISOPEN, sowie FA_FSELCLOSED,
 * nachdem Abbruch oder Ok bettigt wurde bzw. der Selektor auf
 * sonstige Art (AP_TERM,AC_CLOSE,Speichermangel) geschlossen wurde
 * Word 3: Maximale Anzahl zu selektierender Files
 * Word 4/5: Zeiger auf FSEL_REQ:
 */

typedef struct
{
	char *f_path;  /* Startpfad mit Startextension */
	char *f_file;  /* Ggf. Vorgabe fuer das File-Inputfeld */
  	char *label;   /* (Fenster-)berschrift fuer den Selektor */
	char *name;    /* App-Name, der vor die berschrift gesetzt
	                  werden soll oder NULL, dann ermittelt
	                  Freedom einen per Xacc/AV/appl_search */
	int sys_modal; /* 1 = Systemmodalen Selektor/Alert ffnen! */
	int fullpaths; /* Wenn 1, sind im String f_files der Antwort
	                  volle Pfadnamen enthalten, dies ermglicht,
	                  da auch Files aus unterschiedlichen
	                  Directorys (zB per Drag&Drop auf Freedom
	                  "abgeworfen") bergeben werden knnen */
	int quotes;    /* Filenamen, die Spaces enthalten, drfen
	                  von Freedom gequotet werden! */

} FSEL_REQ;


#define FA_FSELISOPEN	0x4568
/* FA_FSELISOPEN: Der Fensterfileselektor ist geffnet worden
 * Word 3: (Fenster)handle des Selektors, oder 0, wenn aus
 * irgendeinem Grund nur ein Systemmodaler Fileselektor geffnet
 * werden konnte. (Interessant zB fr Applikationen, die mehr als
 * einen Fileselektor gleichzeitig zulassen mchten..)
 * Diese Meldung sagt der Applikation auch, das die Daten der
 * FSEL_REQ Struktur nicht mehr bentigt werden
 * Ein -1 in Word 3 bedeutet: Konnte kein Fsel geffnet werden!!
 */

#define FA_FSELCLOSED	0x4569
/* FA_FSELCLOSED: Ein Windowfileselektor wurde geschlossen.
 * (Durch Abbruch oder Ok oder auf auf sonstige Art..)
 * Word 3: (Fenster-)Handle des Selektors
 * Word 4: 0=Abbruch, -1=Anderes Ereignis, 1=Ok
 * Word 5/6: Zeiger auf FSEL_REPLY:
 */

typedef struct
{
	char *f_path;	/* Pfad beim Schliessen des Fsels */
	char *f_files;	/* f_cnt Selektierte Files (durch Spaces getrennt) */
	int f_cnt;	 	/* Anzahl der Files im String f_files */

} FSEL_REP;

#define AF_CLOSEACK		0x4570
/* AF_CLOSEACK: Fselserver kann die Daten jetzt freigeben
 * Bitte unbedingt senden, egal, welcher Wert im Word 4 von
 * FA_FSELCLOSED steht, da ansonsten best. Speicherbloecke
 * nicht freigegeben werden! Terminiert die Applikation mit
 * offenen Fileselektoren, kriegt der Server das auch mit,
 * sofern die Appl. das Xacc-Protokoll beherscht, sptestens
 * aber auch bei seiner Garbage Collection
 * Word 3: (Fenster-)Handle des Selektors
 */

#define AF_SENDMEMSG	0x4571
/* AF_SENDMEMSG: Veranlasst den Server, eine AES-Nachricht fr
 * die in dem Bitfeld markierten Fenster zu senden.. Das knnte der
 * Handler zwar auch selbst, jedoch nur mit maximal 8 AES-Messages!
 * (Experten wissen, warum... (o:)
 * Word 3: AES-Nachrichten-Nummer (zB WM_REDRAW)
 * Word 4-7: Bitfeld (Fensterhandles 0 .. 64)
 */

#endif
